==> haskell-concise-0.1.0.1-366-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 concise
version:              0.1.0.1
visibility:           public
id:                   concise-0.1.0.1-3dqTXrdAnzY5FJpEjx8zNI
key:                  concise-0.1.0.1-3dqTXrdAnzY5FJpEjx8zNI
license:              BSD-3-Clause
copyright:            Copyright (C) 2016  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-concise
synopsis:             Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.

category:             Data, Lenses
abi:                  4c05e36978091e466c3a84b7c0eb165e
exposed:              True
exposed-modules:      Control.Lens.Cons.Extras
import-dirs:          /usr/lib/ghc-9.0.2/site-local/concise-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concise
hs-libraries:         HSconcise-0.1.0.1-3dqTXrdAnzY5FJpEjx8zNI
depends:
    base-4.15.1.0 bytestring-0.10.12.1 lens-5.1-35hOsc17ouGLR87q1aDt7k
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html:         /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concise-0.1.0.1-368-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-concise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 concise
version:              0.1.0.1
visibility:           public
id:                   concise-0.1.0.1-BXABSdZqi5e5BoRA7iVxTf
key:                  concise-0.1.0.1-BXABSdZqi5e5BoRA7iVxTf
license:              BSD-3-Clause
copyright:            Copyright (C) 2016  Fraser Tweedale
maintainer:           frase@frase.id.au
author:               Fraser Tweedale
homepage:             https://github.com/frasertweedale/hs-concise
synopsis:             Utilities for Control.Lens.Cons
description:
    concise provides a handful of functions to extend what you can
    do with Control.Lens.Cons.

category:             Data, Lenses
abi:                  1cabd971c91816540e2465ac1aa5723a
exposed:              True
exposed-modules:      Control.Lens.Cons.Extras
import-dirs:          /usr/lib/ghc-9.0.2/site-local/concise-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/concise-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-concise
hs-libraries:         HSconcise-0.1.0.1-BXABSdZqi5e5BoRA7iVxTf
depends:
    base-4.15.1.0 bytestring-0.10.12.1 lens-5.1-KzHhhLE1jOD6VmHbPqSTp2
    text-1.2.5.0

haddock-interfaces:   /usr/share/doc/haskell-concise/html/concise.haddock
haddock-html:         /usr/share/doc/haskell-concise/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
